==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Surveys/language/lang-swedish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","Ditt Namn");
define("_OK","Ok!");
define("_COMMENT","kommentar");
define("_CONFIGURE","Konfigurera");
define("_LOGINCREATE","Logga in/Skapa ett konto");
define("_THRESHOLD","Trskel");
define("_NOCOMMENTS","Inga kommentarer");
define("_NESTED","Nstlad");
define("_FLAT","Platt");
define("_THREAD","Trdad");
define("_OLDEST","ldst Frst");
define("_NEWEST","Nyaste Frst");
define("_HIGHEST","Hgsta pong frst");
define("_COMMENTSWARNING","Kommentarern gs av respektive postare. Vi tar inte ansvar fr innehllet i dem.");
define("_SCORE","Pong:");
define("_USERINFO","Anvndarinformation");
define("_READREST","Lst resten av denna kommentar...");
define("_REPLY","Svara p detta");
define("_REPLYMAIN","Posta kommentar");
define("_NOSUBJECT","Inget mne");
define("_NOANONCOMMENTS","Inga kommentarer tillts fr anonyma beskare, vnligen <a href=\"modules.php?name=Your_Account\">registrera dig</a>");
define("_PARENT","Frlder");
define("_ROOT","Root");
define("_UCOMMENT","Kommentar");
define("_ALLOWEDHTML","Tillten HTML:");
define("_POSTANON","Posta Anonymt");
define("_EXTRANS","Extrans (html kod till text)");
define("_HTMLFORMATED","HTML Formaterad");
define("_PLAINTEXT","Helt vanlig text");
define("_ONN","p...");
define("_SUBJECT","mne");
define("_SURVEYCOM","Posta kommentar till omrstning");
define("_SURVEYCOMPRE","Frhandsgranska kommentar till omrstning");
define("_NOTRIGHT","Nnting gick t skogen nr vi skickade med en variabel till den hr funktionen. Det hr meddelandet finns hr bara fr att inte stlla till det mer lngre ner.");
define("_DIRECTCOM","Direkt kommentar till omrstning...");
define("_SENDAMSG","Skicka ett meddelande");
define("_PASTSURVEYS","Tidigare Underskningar");



define("_LVOTES","rster");
define("_TOTALVOTES","Totalt antal rster:");
define("_VOTING","Omrstningsbs");
define("_OTHERPOLLS","Andra Underskningar");
define("_CURRENTSURVEY","Nuvarande underskning");
define("_CURRENTPOLLRESULTS","Nuvarande stllning");
define("_PREVIEW","Frhandsgranska");
define("_REFRESH","Uppdatera");
define("_SURVEYS","Underskningar");
define("_ATTACHEDTOARTICLE","- Attached to article:");
define("_SURVEYSATTACHED","Surveys Attached to Articles");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Surveys/language/lang-swedish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","Ditt Namn");
define("_OK","Ok!");
define("_COMMENT","kommentar");
define("_CONFIGURE","Konfigurera");
define("_LOGINCREATE","Logga in/Skapa ett konto");
define("_THRESHOLD","Trskel");
define("_NOCOMMENTS","Inga kommentarer");
define("_NESTED","Nstlad");
define("_FLAT","Platt");
define("_THREAD","Trdad");
define("_OLDEST","ldst Frst");
define("_NEWEST","Nyaste Frst");
define("_HIGHEST","Hgsta pong frst");
define("_COMMENTSWARNING","Kommentarern gs av respektive postare. Vi tar inte ansvar fr innehllet i dem.");
define("_SCORE","Pong:");
define("_USERINFO","Anvndarinformation");
define("_READREST","Lst resten av denna kommentar...");
define("_REPLY","Svara p detta");
define("_REPLYMAIN","Posta kommentar");
define("_NOSUBJECT","Inget mne");
define("_NOANONCOMMENTS","Inga kommentarer tillts fr anonyma beskare, vnligen <a href=\"modules.php?name=Your_Account\">registrera dig</a>");
define("_PARENT","Frlder");
define("_ROOT","Root");
define("_UCOMMENT","Kommentar");
define("_ALLOWEDHTML","Tillten HTML:");
define("_POSTANON","Posta Anonymt");
define("_EXTRANS","Extrans (html kod till text)");
define("_HTMLFORMATED","HTML Formaterad");
define("_PLAINTEXT","Helt vanlig text");
define("_ONN","p...");
define("_SUBJECT","mne");
define("_SURVEYCOM","Posta kommentar till omrstning");
define("_SURVEYCOMPRE","Frhandsgranska kommentar till omrstning");
define("_NOTRIGHT","Nnting gick t skogen nr vi skickade med en variabel till den hr funktionen. Det hr meddelandet finns hr bara fr att inte stlla till det mer lngre ner.");
define("_DIRECTCOM","Direkt kommentar till omrstning...");
define("_SENDAMSG","Skicka ett meddelande");
define("_PASTSURVEYS","Tidigare Underskningar");



define("_LVOTES","rster");
define("_TOTALVOTES","Totalt antal rster:");
define("_VOTING","Omrstningsbs");
define("_OTHERPOLLS","Andra Underskningar");
define("_CURRENTSURVEY","Nuvarande underskning");
define("_CURRENTPOLLRESULTS","Nuvarande stllning");
define("_PREVIEW","Frhandsgranska");
define("_REFRESH","Uppdatera");
define("_SURVEYS","Underskningar");
define("_ATTACHEDTOARTICLE","- Attached to article:");
define("_SURVEYSATTACHED","Surveys Attached to Articles");

?>
